@@ -54,6 +54,7 @@ static gboolean opt_from;
 static gboolean opt_yes;
 static gboolean opt_reinstall;
 static gboolean opt_noninteractive;
+static gboolean opt_or_update;
 
 static GOptionEntry options[] = {
   { "arch", 0, 0, G_OPTION_ARG_STRING, &opt_arch, N_("Arch to install for"), N_("ARCH") },
@@ -71,6 +72,7 @@ static GOptionEntry options[] = {
   { "assumeyes", 'y', 0, G_OPTION_ARG_NONE, &opt_yes, N_("Automatically answer yes for all questions"), NULL },
   { "reinstall", 0, 0, G_OPTION_ARG_NONE, &opt_reinstall, N_("Uninstall first if already installed"), NULL },
   { "noninteractive", 0, 0, G_OPTION_ARG_NONE, &opt_noninteractive, N_("Produce minimal output and don't ask questions"), NULL },
+  { "or-update", 0, 0, G_OPTION_ARG_NONE, &opt_or_update, N_("Update install if already installed"), NULL },
   { NULL }
 };
 
@@ -152,7 +154,7 @@ install_bundle (FlatpakDir *dir,
   if (opt_noninteractive)
     transaction = flatpak_quiet_transaction_new (dir, error);
   else
-    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, error);
+    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, opt_arch != NULL, error);
   if (transaction == NULL)
     return FALSE;
 
@@ -205,7 +207,7 @@ install_from (FlatpakDir *dir,
     {
       g_autoptr(SoupSession) soup_session = NULL;
       soup_session = flatpak_create_soup_session (PACKAGE_STRING);
-      file_data = flatpak_load_http_uri (soup_session, filename, 0, NULL, NULL, cancellable, error);
+      file_data = flatpak_load_http_uri (soup_session, filename, 0, NULL, NULL, NULL, cancellable, error);
       if (file_data == NULL)
         {
           g_prefix_error (error, "Can't load uri %s: ", filename);
@@ -225,7 +227,7 @@ install_from (FlatpakDir *dir,
   if (opt_noninteractive)
     transaction = flatpak_quiet_transaction_new (dir, error);
   else
-    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, error);
+    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, opt_arch != NULL, error);
   if (transaction == NULL)
     return FALSE;
 
@@ -446,7 +448,7 @@ flatpak_builtin_install (int argc, char **argv, GCancellable *cancellable, GErro
   if (opt_noninteractive)
     transaction = flatpak_quiet_transaction_new (dir, error);
   else
-    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, error);
+    transaction = flatpak_cli_transaction_new (dir, opt_yes, TRUE, opt_arch != NULL, error);
   if (transaction == NULL)
     return FALSE;
 
@@ -502,13 +504,21 @@ flatpak_builtin_install (int argc, char **argv, GCancellable *cancellable, GErro
       if (!flatpak_resolve_matching_refs (remote, dir, opt_yes, refs, id, &ref, error))
         return FALSE;
 
-      if (!flatpak_transaction_add_install (transaction, remote, ref, (const char **) opt_subpaths, error))
+      if (!flatpak_transaction_add_install (transaction, remote, ref, (const char **) opt_subpaths, &local_error))
         {
-          if (!g_error_matches (*error, FLATPAK_ERROR, FLATPAK_ERROR_ALREADY_INSTALLED))
-            return FALSE;
+          if (!g_error_matches (local_error, FLATPAK_ERROR, FLATPAK_ERROR_ALREADY_INSTALLED))
+            {
+              g_propagate_error (error, g_steal_pointer (&local_error));
+              return FALSE;
+            }
 
-          g_printerr (_("Skipping: %s\n"), (*error)->message);
-          g_clear_error (error);
+          if (opt_or_update)
+            {
+              if (!flatpak_transaction_add_update (transaction, ref, (const char **) opt_subpaths, NULL, error))
+                return FALSE;
+            }
+          else
+            g_printerr (_("Skipping: %s\n"), local_error->message);
         }
     }
 
