@@ -65,7 +65,7 @@ kill_instance (const char *id,
   g_debug ("Killed %d instances", killed);
 
   if (killed == 0)
-    return flatpak_fail (error, _("%s is not running."), id);
+    return flatpak_fail (error, _("%s is not running"), id);
 
   return TRUE;
 }
