@@ -272,7 +272,7 @@ ls_remote (GHashTable *refs_hash, const char **arches, const char *app_runtime,
           if (sparse)
             {
               const char *eol;
-              if (!opt_all && (g_variant_lookup (sparse, "eol", "&s", &eol) || g_variant_lookup (sparse, "eolr", "&s", &eol)))
+              if (!opt_all && (g_variant_lookup (sparse, FLATPAK_SPARSE_CACHE_KEY_ENDOFLINE, "&s", &eol) || g_variant_lookup (sparse, FLATPAK_SPARSE_CACHE_KEY_ENDOFLINE_REBASE, "&s", &eol)))
                 continue;
             }
 
@@ -285,7 +285,7 @@ ls_remote (GHashTable *refs_hash, const char **arches, const char *app_runtime,
 
               if (!flatpak_remote_state_lookup_cache (state, ref,
                                                       &download_size, &installed_size, &metadata,
-                                                      error))
+                                                      NULL, error))
                 return FALSE;
 
               metakey = g_key_file_new ();
@@ -365,9 +365,9 @@ ls_remote (GHashTable *refs_hash, const char **arches, const char *app_runtime,
                     {
                       const char *eol;
 
-                      if (g_variant_lookup (sparse, "eol", "&s", &eol))
+                      if (g_variant_lookup (sparse, FLATPAK_SPARSE_CACHE_KEY_ENDOFLINE, "&s", &eol))
                         flatpak_table_printer_append_with_comma_printf (printer, "eol=%s", eol);
-                      if (g_variant_lookup (sparse, "eolr", "&s", &eol))
+                      if (g_variant_lookup (sparse, FLATPAK_SPARSE_CACHE_KEY_ENDOFLINE_REBASE, "&s", &eol))
                         flatpak_table_printer_append_with_comma_printf (printer, "eol-rebase=%s", eol);
                     }
                 }
@@ -411,7 +411,10 @@ flatpak_builtin_remote_ls (int argc, char **argv, GCancellable *cancellable, GEr
     return FALSE;
 
   if (!opt_app && !opt_runtime)
-    opt_app = opt_runtime = TRUE;
+    {
+      opt_app = TRUE;
+      opt_runtime = !opt_app_runtime;
+    }
 
   if (argc > 2)
     return usage_error (context, _("Too many arguments"), error);
