@@ -53,6 +53,9 @@ static char *opt_icon;
 static char *opt_default_branch;
 static char *opt_url;
 static char *opt_collection_id = NULL;
+static char *opt_authenticator_name = NULL;
+static char **opt_authenticator_options = NULL;
+static gboolean opt_authenticator_install = -1;
 static char **opt_gpg_import;
 
 
@@ -82,10 +85,13 @@ static GOptionEntry common_options[] = {
   { "no-filter", 0, 0, G_OPTION_ARG_NONE, &opt_no_filter, N_("Disable local filter"), NULL },
   { "filter", 0, 0, G_OPTION_ARG_FILENAME, &opt_filter, N_("Set path to local filter FILE"), N_("FILE") },
   { "disable", 0, 0, G_OPTION_ARG_NONE, &opt_disable, N_("Disable the remote"), NULL },
+  { "authenticator-name", 0, 0, G_OPTION_ARG_STRING, &opt_authenticator_name, N_("Name of authenticator"), N_("NAME") },
+  { "authenticator-option", 0, 0, G_OPTION_ARG_STRING_ARRAY, &opt_authenticator_options, N_("Authenticator options"), N_("KEY=VALUE") },
+  { "authenticator-install", 0, 0, G_OPTION_ARG_NONE, &opt_authenticator_install, N_("Autoinstall authenticator"), NULL },
+  { "no-authenticator-install", 0, G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &opt_authenticator_install, N_("Don't autoinstall authenticator"), NULL },
   { NULL }
 };
 
-
 static GKeyFile *
 get_config_from_opts (FlatpakDir *dir, const char *remote_name, gboolean *changed)
 {
@@ -219,6 +225,35 @@ get_config_from_opts (FlatpakDir *dir, const char *remote_name, gboolean *change
       *changed = TRUE;
     }
 
+  if (opt_authenticator_name)
+    {
+      g_key_file_set_string (config, group, "xa.authenticator-name", opt_authenticator_name);
+      g_key_file_set_boolean (config, group, "xa.authenticator-name-is-set", TRUE);
+      *changed = TRUE;
+    }
+
+  if (opt_authenticator_install != -1)
+    {
+      g_key_file_set_boolean (config, group, "xa.authenticator-install", opt_authenticator_install);
+      g_key_file_set_boolean (config, group, "xa.authenticator-install-is-set", TRUE);
+      *changed = TRUE;
+    }
+
+  if (opt_authenticator_options)
+    {
+      for (int i = 0; opt_authenticator_options[i] != NULL; i++)
+        {
+          g_auto(GStrv) split = g_strsplit (opt_authenticator_options[i], "=", 2);
+          g_autofree char *key = g_strdup_printf ("xa.authenticator-options.%s", split[0]);
+
+          if (split[0] == NULL || split[1] == NULL || *split[1] == 0)
+            g_key_file_remove_key (config, group, key, NULL);
+          else
+            g_key_file_set_string (config, group, key, split[1]);
+        }
+      *changed = TRUE;
+    }
+
   return config;
 }
 
@@ -255,7 +290,7 @@ flatpak_builtin_remote_modify (int argc, char **argv, GCancellable *cancellable,
       g_autoptr(GError) local_error = NULL;
 
       g_print (_("Updating extra metadata from remote summary for %s\n"), remote_name);
-      if (!flatpak_dir_update_remote_configuration (preferred_dir, remote_name, cancellable, &local_error))
+      if (!flatpak_dir_update_remote_configuration (preferred_dir, remote_name, NULL, NULL, cancellable, &local_error))
         {
           g_printerr (_("Error updating extra metadata for '%s': %s\n"), remote_name, local_error->message);
           return flatpak_fail (error, _("Could not update extra metadata for %s"), remote_name);
@@ -266,6 +301,9 @@ flatpak_builtin_remote_modify (int argc, char **argv, GCancellable *cancellable,
         return FALSE;
     }
 
+  if (opt_authenticator_name && !g_dbus_is_name (opt_authenticator_name))
+    return flatpak_fail (error, _("Invalid authenticator name %s"), opt_authenticator_name);
+
   config = get_config_from_opts (preferred_dir, remote_name, &changed);
 
   if (opt_gpg_import != NULL)
