@@ -85,6 +85,7 @@ BUILTINPROTO (remote_ls)
 BUILTINPROTO (remote_info)
 BUILTINPROTO (remote_list)
 BUILTINPROTO (install)
+BUILTINPROTO (mask)
 BUILTINPROTO (update)
 BUILTINPROTO (make_current_app)
 BUILTINPROTO (uninstall)
@@ -108,6 +109,7 @@ BUILTINPROTO (document_unexport)
 BUILTINPROTO (document_info)
 BUILTINPROTO (document_list)
 BUILTINPROTO (permission_remove)
+BUILTINPROTO (permission_set)
 BUILTINPROTO (permission_list)
 BUILTINPROTO (permission_show)
 BUILTINPROTO (permission_reset)
