@@ -21,8 +21,8 @@
 #include "config.h"
 #include "string.h"
 
-#include "flatpak-json-oci.h"
-#include "flatpak-utils.h"
+#include "flatpak-json-oci-private.h"
+#include "flatpak-utils-private.h"
 #include "libglnx.h"
 
 const char *
@@ -40,7 +40,7 @@ flatpak_arch_to_oci_arch (const char *flatpak_arch)
 FlatpakOciDescriptor *
 flatpak_oci_descriptor_new (const char *mediatype,
                             const char *digest,
-                            gint64 size)
+                            gint64      size)
 {
   FlatpakOciDescriptor *desc = g_new0 (FlatpakOciDescriptor, 1);
 
@@ -61,10 +61,10 @@ flatpak_oci_descriptor_copy (FlatpakOciDescriptor *source,
   dest->mediatype = g_strdup (source->mediatype);
   dest->digest = g_strdup (source->digest);
   dest->size = source->size;
-  dest->urls = g_strdupv ((char **)source->urls);
+  dest->urls = g_strdupv ((char **) source->urls);
   dest->annotations = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
   if (source->annotations)
-    flatpak_oci_copy_annotations (source->annotations, dest->annotations);
+    flatpak_oci_copy_labels (source->annotations, dest->annotations);
 }
 
 void
@@ -89,7 +89,7 @@ static FlatpakJsonProp flatpak_oci_descriptor_props[] = {
   FLATPAK_JSON_STRING_PROP (FlatpakOciDescriptor, digest, "digest"),
   FLATPAK_JSON_INT64_PROP (FlatpakOciDescriptor, size, "size"),
   FLATPAK_JSON_STRV_PROP (FlatpakOciDescriptor, urls, "urls"),
-  FLATPAK_JSON_STRMAP_PROP(FlatpakOciDescriptor, annotations, "annotations"),
+  FLATPAK_JSON_STRMAP_PROP (FlatpakOciDescriptor, annotations, "annotations"),
   FLATPAK_JSON_LAST_PROP
 };
 
@@ -173,11 +173,12 @@ flatpak_oci_versioned_init (FlatpakOciVersioned *self)
 }
 
 FlatpakOciVersioned *
-flatpak_oci_versioned_from_json (GBytes *bytes, GError **error)
+flatpak_oci_versioned_from_json (GBytes *bytes,
+                                 GError **error)
 {
   g_autoptr(JsonParser) parser = NULL;
   JsonNode *root = NULL;
-  const gchar *mediatype;
+  const gchar *mediatype = NULL;
   JsonObject *object;
 
   parser = json_parser_new ();
@@ -190,7 +191,9 @@ flatpak_oci_versioned_from_json (GBytes *bytes, GError **error)
   root = json_parser_get_root (parser);
   object = json_node_get_object (root);
 
-  mediatype = json_object_get_string_member (object, "mediaType");
+  if (json_object_has_member (object, "mediaType"))
+    mediatype = json_object_get_string_member (object, "mediaType");
+
   if (mediatype == NULL)
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
@@ -198,7 +201,9 @@ flatpak_oci_versioned_from_json (GBytes *bytes, GError **error)
       return NULL;
     }
 
-  if (strcmp (mediatype, FLATPAK_OCI_MEDIA_TYPE_IMAGE_MANIFEST) == 0)
+  /* The docker v2 image manifest is similar enough that we can just load it, it does not have the annotation field though */
+  if (strcmp (mediatype, FLATPAK_OCI_MEDIA_TYPE_IMAGE_MANIFEST) == 0 ||
+      strcmp (mediatype, FLATPAK_DOCKER_MEDIA_TYPE_IMAGE_MANIFEST2) == 0)
     return (FlatpakOciVersioned *) flatpak_json_from_node (root, FLATPAK_TYPE_OCI_MANIFEST, error);
 
   if (strcmp (mediatype, FLATPAK_OCI_MEDIA_TYPE_IMAGE_INDEX) == 0)
@@ -209,6 +214,26 @@ flatpak_oci_versioned_from_json (GBytes *bytes, GError **error)
   return NULL;
 }
 
+FlatpakOciImage *
+flatpak_oci_image_from_json (GBytes *bytes,
+                             GError **error)
+{
+  g_autoptr(JsonParser) parser = NULL;
+  JsonNode *root = NULL;
+
+  parser = json_parser_new ();
+  if (!json_parser_load_from_data (parser,
+                                   g_bytes_get_data (bytes, NULL),
+                                   g_bytes_get_size (bytes),
+                                   error))
+    return NULL;
+
+  root = json_parser_get_root (parser);
+
+  return (FlatpakOciImage *) flatpak_json_from_node (root, FLATPAK_TYPE_OCI_IMAGE, error);
+}
+
+
 const char *
 flatpak_oci_versioned_get_mediatype (FlatpakOciVersioned *self)
 {
@@ -245,9 +270,9 @@ flatpak_oci_manifest_class_init (FlatpakOciManifestClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   FlatpakJsonClass *json_class = FLATPAK_JSON_CLASS (klass);
   static FlatpakJsonProp props[] = {
-    FLATPAK_JSON_STRUCT_PROP(FlatpakOciManifest, config, "config", flatpak_oci_descriptor_props),
-    FLATPAK_JSON_STRUCTV_PROP(FlatpakOciManifest, layers, "layers", flatpak_oci_descriptor_props),
-    FLATPAK_JSON_STRMAP_PROP(FlatpakOciManifest, annotations, "annotations"),
+    FLATPAK_JSON_STRUCT_PROP (FlatpakOciManifest, config, "config", flatpak_oci_descriptor_props),
+    FLATPAK_JSON_STRUCTV_PROP (FlatpakOciManifest, layers, "layers", flatpak_oci_descriptor_props),
+    FLATPAK_JSON_STRMAP_PROP (FlatpakOciManifest, annotations, "annotations"),
     FLATPAK_JSON_LAST_PROP
   };
 
@@ -276,7 +301,7 @@ flatpak_oci_manifest_new (void)
 }
 
 void
-flatpak_oci_manifest_set_config (FlatpakOciManifest *self,
+flatpak_oci_manifest_set_config (FlatpakOciManifest   *self,
                                  FlatpakOciDescriptor *desc)
 {
   g_free (self->config.mediatype);
@@ -298,15 +323,16 @@ ptrv_count (gpointer *ptrs)
 }
 
 void
-flatpak_oci_manifest_set_layer (FlatpakOciManifest  *self,
+flatpak_oci_manifest_set_layer (FlatpakOciManifest   *self,
                                 FlatpakOciDescriptor *desc)
 {
   FlatpakOciDescriptor *descs[2] = { desc, NULL };
+
   flatpak_oci_manifest_set_layers (self, descs);
 }
 
 void
-flatpak_oci_manifest_set_layers (FlatpakOciManifest *self,
+flatpak_oci_manifest_set_layers (FlatpakOciManifest    *self,
                                  FlatpakOciDescriptor **descs)
 {
   int i, count;
@@ -315,7 +341,7 @@ flatpak_oci_manifest_set_layers (FlatpakOciManifest *self,
     flatpak_oci_descriptor_free (self->layers[i]);
   g_free (self->layers);
 
-  count = ptrv_count ((gpointer *)descs);
+  count = ptrv_count ((gpointer *) descs);
 
   self->layers = g_new0 (FlatpakOciDescriptor *, count + 1);
   for (i = 0; i < count; i++)
@@ -330,12 +356,12 @@ flatpak_oci_manifest_set_layers (FlatpakOciManifest *self,
 int
 flatpak_oci_manifest_get_n_layers (FlatpakOciManifest *self)
 {
-  return ptrv_count ((gpointer *)self->layers);
+  return ptrv_count ((gpointer *) self->layers);
 }
 
 const char *
 flatpak_oci_manifest_get_layer_digest (FlatpakOciManifest *self,
-                                      int i)
+                                       int                 i)
 {
   return self->layers[i]->digest;
 }
@@ -371,8 +397,8 @@ flatpak_oci_index_class_init (FlatpakOciIndexClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   FlatpakJsonClass *json_class = FLATPAK_JSON_CLASS (klass);
   static FlatpakJsonProp props[] = {
-    FLATPAK_JSON_STRUCTV_PROP(FlatpakOciIndex, manifests, "manifests", flatpak_oci_manifest_descriptor_props),
-    FLATPAK_JSON_STRMAP_PROP(FlatpakOciIndex, annotations, "annotations"),
+    FLATPAK_JSON_STRUCTV_PROP (FlatpakOciIndex, manifests, "manifests", flatpak_oci_manifest_descriptor_props),
+    FLATPAK_JSON_STRMAP_PROP (FlatpakOciIndex, annotations, "annotations"),
     FLATPAK_JSON_LAST_PROP
   };
 
@@ -409,37 +435,34 @@ manifest_desc_for_desc (FlatpakOciDescriptor *src_descriptor, const char *ref)
   flatpak_oci_descriptor_copy (src_descriptor, &desc->parent);
 
   g_hash_table_replace (desc->parent.annotations,
-			g_strdup ("org.opencontainers.image.ref.name"),
-			g_strdup (ref));
+                        g_strdup ("org.opencontainers.image.ref.name"),
+                        g_strdup (ref));
   return desc;
 }
 
 int
 flatpak_oci_index_get_n_manifests (FlatpakOciIndex *self)
 {
-  return ptrv_count ((gpointer *)self->manifests);
+  return ptrv_count ((gpointer *) self->manifests);
 }
 
 void
-flatpak_oci_index_add_manifest (FlatpakOciIndex *self,
+flatpak_oci_index_add_manifest (FlatpakOciIndex      *self,
+                                const char           *ref,
                                 FlatpakOciDescriptor *desc)
 {
   FlatpakOciManifestDescriptor *m;
-  const char *m_ref = NULL;
   int count;
 
-  if (desc->annotations != NULL)
-    m_ref = g_hash_table_lookup (desc->annotations, "org.flatpak.ref");
-
-  if (m_ref != NULL)
-    flatpak_oci_index_remove_manifest (self, m_ref);
+  if (ref != NULL)
+    flatpak_oci_index_remove_manifest (self, ref);
 
   count = flatpak_oci_index_get_n_manifests (self);
 
-  m = manifest_desc_for_desc (desc, m_ref);
+  m = manifest_desc_for_desc (desc, ref);
   self->manifests = g_renew (FlatpakOciManifestDescriptor *, self->manifests, count + 2);
   self->manifests[count] = m;
-  self->manifests[count+1] = NULL;
+  self->manifests[count + 1] = NULL;
 }
 
 const char *
@@ -457,7 +480,7 @@ flatpak_oci_manifest_descriptor_get_ref (FlatpakOciManifestDescriptor *m)
 
 static int
 index_find_ref (FlatpakOciIndex *self,
-                const char *ref)
+                const char      *ref)
 {
   int i;
 
@@ -480,7 +503,7 @@ index_find_ref (FlatpakOciIndex *self,
 
 FlatpakOciManifestDescriptor *
 flatpak_oci_index_get_manifest (FlatpakOciIndex *self,
-                                const char *ref)
+                                const char      *ref)
 {
   int i = index_find_ref (self, ref);
 
@@ -526,8 +549,10 @@ flatpak_oci_index_remove_manifest (FlatpakOciIndex *self,
   if (i < 0)
     return FALSE;
 
+  flatpak_oci_manifest_descriptor_free (self->manifests[i]);
+
   for (; self->manifests[i] != NULL; i++)
-    self->manifests[i] = self->manifests[i+1];
+    self->manifests[i] = self->manifests[i + 1];
 
   return TRUE;
 }
@@ -601,7 +626,7 @@ flatpak_oci_image_class_init (FlatpakOciImageClass *klass)
     FLATPAK_JSON_STRV_PROP (FlatpakOciImageConfig, cmd, "Cmd"),
     FLATPAK_JSON_BOOLMAP_PROP (FlatpakOciImageConfig, volumes, "Volumes"),
     FLATPAK_JSON_STRING_PROP (FlatpakOciImageConfig, working_dir, "WorkingDir"),
-    FLATPAK_JSON_STRMAP_PROP(FlatpakOciImageConfig, labels, "Labels"),
+    FLATPAK_JSON_STRMAP_PROP (FlatpakOciImageConfig, labels, "Labels"),
     FLATPAK_JSON_LAST_PROP
   };
   static FlatpakJsonProp rootfs_props[] = {
@@ -662,7 +687,7 @@ flatpak_oci_image_new (void)
 
 void
 flatpak_oci_image_set_created (FlatpakOciImage *image,
-                              const char *created)
+                               const char      *created)
 {
   g_free (image->created);
   image->created = g_strdup (created);
@@ -670,7 +695,7 @@ flatpak_oci_image_set_created (FlatpakOciImage *image,
 
 void
 flatpak_oci_image_set_architecture (FlatpakOciImage *image,
-                                   const char *arch)
+                                    const char      *arch)
 {
   g_free (image->architecture);
   image->architecture = g_strdup (arch);
@@ -678,7 +703,7 @@ flatpak_oci_image_set_architecture (FlatpakOciImage *image,
 
 void
 flatpak_oci_image_set_os (FlatpakOciImage *image,
-                         const char *os)
+                          const char      *os)
 {
   g_free (image->os);
   image->os = g_strdup (os);
@@ -686,15 +711,23 @@ flatpak_oci_image_set_os (FlatpakOciImage *image,
 
 void
 flatpak_oci_image_set_layers (FlatpakOciImage *image,
-                             const char **layers)
+                              const char     **layers)
 {
   g_strfreev (image->rootfs.diff_ids);
-  image->rootfs.diff_ids = g_strdupv ((char **)layers);
+  image->rootfs.diff_ids = g_strdupv ((char **) layers);
+}
+
+GHashTable *
+flatpak_oci_image_get_labels (FlatpakOciImage *self)
+{
+  if (self->config.labels == NULL)
+    self->config.labels = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+  return self->config.labels;
 }
 
 void
 flatpak_oci_image_set_layer (FlatpakOciImage *image,
-                             const char *layer)
+                             const char      *layer)
 {
   const char *layers[] = {layer, NULL};
 
@@ -702,8 +735,8 @@ flatpak_oci_image_set_layer (FlatpakOciImage *image,
 }
 
 void
-flatpak_oci_export_annotations (GHashTable *source,
-                                GHashTable *dest)
+flatpak_oci_export_labels (GHashTable *source,
+                           GHashTable *dest)
 {
   const char *keys[] = {
     "org.flatpak.ref",
@@ -713,6 +746,9 @@ flatpak_oci_export_annotations (GHashTable *source,
   };
   int i;
 
+  if (source == NULL)
+    return;
+
   for (i = 0; i < G_N_ELEMENTS (keys); i++)
     {
       const char *key = keys[i];
@@ -725,38 +761,63 @@ flatpak_oci_export_annotations (GHashTable *source,
 }
 
 void
-flatpak_oci_copy_annotations (GHashTable *source,
-                              GHashTable *dest)
+flatpak_oci_copy_labels (GHashTable *source,
+                         GHashTable *dest)
 {
- GHashTableIter iter;
- gpointer key, value;
+  GHashTableIter iter;
+  gpointer key, value;
 
- g_hash_table_iter_init (&iter, source);
- while (g_hash_table_iter_next (&iter, &key, &value))
-   g_hash_table_replace (dest,
-                         g_strdup ((char *)key),
-                         g_strdup ((char *)value));
+  g_hash_table_iter_init (&iter, source);
+  while (g_hash_table_iter_next (&iter, &key, &value))
+    g_hash_table_replace (dest,
+                          g_strdup ((char *) key),
+                          g_strdup ((char *) value));
+}
+
+int
+flatpak_oci_image_add_history (FlatpakOciImage *image)
+{
+  FlatpakOciImageHistory **old;
+  int i, index, old_len;
+
+  old = image->history;
+
+  for (old_len = 0; old != NULL && old[old_len] != NULL; old_len++)
+    ;
+
+  image->history = g_new0 (FlatpakOciImageHistory *, old_len + 2);
+  for (i = 0; i < old_len; i++)
+    image->history[i] = old[i];
+
+  index = i;
+
+  image->history[i++] = g_new0 (FlatpakOciImageHistory, 1);
+  image->history[i++] = NULL;
+
+  g_free (old);
+
+  return index;
 }
 
 static void
-add_annotation (GHashTable *annotations, const char *key, const char *value)
+add_label (GHashTable *labels, const char *key, const char *value)
 {
-    g_hash_table_replace (annotations,
-                          g_strdup (key),
-                          g_strdup (value));
+  g_hash_table_replace (labels,
+                        g_strdup (key),
+                        g_strdup (value));
 }
 
 void
-flatpak_oci_add_annotations_for_commit (GHashTable *annotations,
-                                       const char *ref,
-                                       const char *commit,
-                                       GVariant *commit_data)
+flatpak_oci_add_labels_for_commit (GHashTable *labels,
+                                   const char *ref,
+                                   const char *commit,
+                                   GVariant   *commit_data)
 {
   if (ref)
-    add_annotation (annotations,"org.flatpak.ref", ref);
+    add_label (labels, "org.flatpak.ref", ref);
 
   if (commit)
-    add_annotation (annotations,"org.flatpak.commit", commit);
+    add_label (labels, "org.flatpak.commit", commit);
 
   if (commit_data)
     {
@@ -769,7 +830,7 @@ flatpak_oci_add_annotations_for_commit (GHashTable *annotations,
 
       parent = ostree_commit_get_parent (commit_data);
       if (parent)
-        add_annotation (annotations, "org.flatpak.parent-commit", parent);
+        add_label (labels, "org.flatpak.parent-commit", parent);
 
       metadata = g_variant_get_child_value (commit_data, 0);
       for (i = 0; i < g_variant_n_children (metadata); i++)
@@ -784,61 +845,66 @@ flatpak_oci_add_annotations_for_commit (GHashTable *annotations,
           full_key = g_strdup_printf ("org.flatpak.commit-metadata.%s", key);
 
           value_base64 = g_base64_encode (g_variant_get_data (value), g_variant_get_size (value));
-          add_annotation (annotations, full_key, value_base64);
+          add_label (labels, full_key, value_base64);
         }
 
       timestamp = g_strdup_printf ("%"G_GUINT64_FORMAT, ostree_commit_get_timestamp (commit_data));
-      add_annotation (annotations, "org.flatpak.timestamp", timestamp);
+      add_label (labels, "org.flatpak.timestamp", timestamp);
 
       g_variant_get_child (commit_data, 3, "s", &subject);
-      add_annotation (annotations, "org.flatpak.subject", subject);
+      add_label (labels, "org.flatpak.subject", subject);
 
       g_variant_get_child (commit_data, 4, "s", &body);
-      add_annotation (annotations, "org.flatpak.body", body);
-   }
+      add_label (labels, "org.flatpak.body", body);
+    }
 }
 
 void
-flatpak_oci_parse_commit_annotations (GHashTable *annotations,
-                                      guint64 *out_timestamp,
-                                      char **out_subject,
-                                      char **out_body,
-                                      char **out_ref,
-                                      char **out_commit,
-                                      char **out_parent_commit,
-                                      GVariantBuilder *metadata_builder)
+flatpak_oci_parse_commit_labels (GHashTable      *labels,
+                                 guint64         *out_timestamp,
+                                 char           **out_subject,
+                                 char           **out_body,
+                                 char           **out_ref,
+                                 char           **out_commit,
+                                 char           **out_parent_commit,
+                                 GVariantBuilder *metadata_builder)
 {
   const char *oci_timestamp, *oci_subject, *oci_body, *oci_parent_commit, *oci_commit, *oci_ref;
   GHashTableIter iter;
   gpointer _key, _value;
 
-  oci_ref = g_hash_table_lookup (annotations, "org.flatpak.ref");
+  oci_ref = g_hash_table_lookup (labels, "org.flatpak.ref");
+
+  /* Early return if this is not a flatpak manifest  */
+  if (oci_ref == NULL)
+    return;
+
   if (oci_ref != NULL && out_ref != NULL && *out_ref == NULL)
     *out_ref = g_strdup (oci_ref);
 
-  oci_commit = g_hash_table_lookup (annotations, "org.flatpak.commit");
+  oci_commit = g_hash_table_lookup (labels, "org.flatpak.commit");
   if (oci_commit != NULL && out_commit != NULL && *out_commit == NULL)
     *out_commit = g_strdup (oci_commit);
 
-  oci_parent_commit = g_hash_table_lookup (annotations, "org.flatpak.parent-commit");
+  oci_parent_commit = g_hash_table_lookup (labels, "org.flatpak.parent-commit");
   if (oci_parent_commit != NULL && out_parent_commit != NULL && *out_parent_commit == NULL)
     *out_parent_commit = g_strdup (oci_parent_commit);
 
-  oci_timestamp = g_hash_table_lookup (annotations, "org.flatpak.timestamp");
+  oci_timestamp = g_hash_table_lookup (labels, "org.flatpak.timestamp");
   if (oci_timestamp != NULL && out_timestamp != NULL && *out_timestamp == 0)
     *out_timestamp = g_ascii_strtoull (oci_timestamp, NULL, 10);
 
-  oci_subject = g_hash_table_lookup (annotations, "org.flatpak.subject");
+  oci_subject = g_hash_table_lookup (labels, "org.flatpak.subject");
   if (oci_subject != NULL && out_subject != NULL && *out_subject == NULL)
     *out_subject = g_strdup (oci_subject);
 
-  oci_body = g_hash_table_lookup (annotations, "org.flatpak.body");
+  oci_body = g_hash_table_lookup (labels, "org.flatpak.body");
   if (oci_body != NULL && out_body != NULL && *out_body == NULL)
     *out_body = g_strdup (oci_body);
 
   if (metadata_builder)
     {
-      g_hash_table_iter_init (&iter, annotations);
+      g_hash_table_iter_init (&iter, labels);
       while (g_hash_table_iter_next (&iter, &_key, &_value))
         {
           const char *key = _key;
@@ -852,7 +918,7 @@ flatpak_oci_parse_commit_annotations (GHashTable *annotations,
           key += strlen ("org.flatpak.commit-metadata.");
 
           bin = g_base64_decode (value, &bin_len);
-          data = g_variant_ref_sink (g_variant_new_from_data (G_VARIANT_TYPE("v"), bin, bin_len, FALSE,
+          data = g_variant_ref_sink (g_variant_new_from_data (G_VARIANT_TYPE ("v"), bin, bin_len, FALSE,
                                                               g_free, bin));
           g_variant_builder_add (metadata_builder, "{s@v}", key, data);
         }
@@ -902,8 +968,8 @@ flatpak_oci_signature_class_init (FlatpakOciSignatureClass *klass)
   };
   static FlatpakJsonProp critical_props[] = {
     FLATPAK_JSON_MANDATORY_STRING_PROP (FlatpakOciSignatureCritical, type, "type"),
-    FLATPAK_JSON_MANDATORY_STRICT_STRUCT_PROP(FlatpakOciSignatureCritical, image, "image", image_props),
-    FLATPAK_JSON_MANDATORY_STRICT_STRUCT_PROP(FlatpakOciSignatureCritical, identity, "identity", identity_props),
+    FLATPAK_JSON_MANDATORY_STRICT_STRUCT_PROP (FlatpakOciSignatureCritical, image, "image", image_props),
+    FLATPAK_JSON_MANDATORY_STRICT_STRUCT_PROP (FlatpakOciSignatureCritical, identity, "identity", identity_props),
     FLATPAK_JSON_LAST_PROP
   };
   static FlatpakJsonProp optional_props[] = {
@@ -1015,8 +1081,8 @@ flatpak_oci_index_response_class_init (FlatpakOciIndexResponseClass *klass)
     FLATPAK_JSON_STRING_PROP (FlatpakOciIndexImage, mediatype, "MediaType"),
     FLATPAK_JSON_STRING_PROP (FlatpakOciIndexImage, os, "OS"),
     FLATPAK_JSON_STRING_PROP (FlatpakOciIndexImage, architecture, "Architecture"),
-    FLATPAK_JSON_STRMAP_PROP(FlatpakOciIndexImage, annotations, "Annotations"),
-    FLATPAK_JSON_STRMAP_PROP(FlatpakOciIndexImage, labels, "Labels"),
+    FLATPAK_JSON_STRMAP_PROP (FlatpakOciIndexImage, annotations, "Annotations"),
+    FLATPAK_JSON_STRMAP_PROP (FlatpakOciIndexImage, labels, "Labels"),
     FLATPAK_JSON_STRV_PROP (FlatpakOciIndexImage, tags, "Tags"),
     FLATPAK_JSON_LAST_PROP
   };
