@@ -132,7 +132,21 @@ struct _FlatpakTransactionClass
                                         const char         *rebased_to_ref,
                                         const char        **previous_ids);
 
-  gpointer padding[8];
+  gboolean (*webflow_start) (FlatpakTransaction *transaction,
+                             const char         *remote,
+                             const char         *url,
+                             GVariant           *options,
+                             guint               id);
+  void (*webflow_done) (FlatpakTransaction *transaction,
+                        GVariant           *options,
+                        guint               id);
+
+  gboolean (*basic_auth_start) (FlatpakTransaction *transaction,
+                                const char         *remote,
+                                const char         *realm,
+                                GVariant           *options,
+                                guint               id);
+  gpointer padding[5];
 };
 
 FLATPAK_EXTERN
@@ -142,7 +156,7 @@ FlatpakTransaction *flatpak_transaction_new_for_installation (FlatpakInstallatio
 
 FLATPAK_EXTERN
 void        flatpak_transaction_progress_set_update_frequency (FlatpakTransactionProgress *self,
-                                                               guint                       update_frequency);
+                                                               guint                       update_interval);
 FLATPAK_EXTERN
 char *      flatpak_transaction_progress_get_status (FlatpakTransactionProgress *self);
 FLATPAK_EXTERN
@@ -180,9 +194,13 @@ FLATPAK_EXTERN
 void                flatpak_transaction_set_no_pull (FlatpakTransaction *self,
                                                      gboolean            no_pull);
 FLATPAK_EXTERN
+gboolean            flatpak_transaction_get_no_pull (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_no_deploy (FlatpakTransaction *self,
                                                        gboolean            no_deploy);
 FLATPAK_EXTERN
+gboolean            flatpak_transaction_get_no_deploy (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_disable_static_deltas (FlatpakTransaction *self,
                                                                    gboolean            disable_static_deltas);
 FLATPAK_EXTERN
@@ -204,6 +222,11 @@ FLATPAK_EXTERN
 void                flatpak_transaction_set_default_arch (FlatpakTransaction *self,
                                                           const char         *arch);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_parent_window (FlatpakTransaction *self,
+                                                           const char *parent_window);
+FLATPAK_EXTERN
+const char *        flatpak_transaction_get_parent_window (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_add_dependency_source (FlatpakTransaction  *self,
                                                                FlatpakInstallation *installation);
 FLATPAK_EXTERN
@@ -219,6 +242,16 @@ FlatpakInstallation *flatpak_transaction_get_installation (FlatpakTransaction *s
 FLATPAK_EXTERN
 GList *flatpak_transaction_get_operations (FlatpakTransaction *self);
 
+FLATPAK_EXTERN
+void               flatpak_transaction_abort_webflow (FlatpakTransaction *self,
+                                                      guint               id);
+FLATPAK_EXTERN
+void               flatpak_transaction_complete_basic_auth (FlatpakTransaction *self,
+                                                            guint id,
+                                                            const char *user,
+                                                            const char *password,
+                                                            GVariant *options);
+
 FLATPAK_EXTERN
 gboolean            flatpak_transaction_add_install (FlatpakTransaction *self,
                                                      const char         *remote,
