@@ -21,10 +21,8 @@ set -euo pipefail
 
 . $(dirname $0)/libtest.sh
 
-$(dirname $0)/test-webserver.sh "" "python $test_srcdir/http-utils-test-server.py 0"
-FLATPAK_HTTP_PID=$(cat httpd-pid)
-mv httpd-port httpd-port-main
-port=$(cat httpd-port-main)
+httpd http-utils-test-server.py .
+port=$(cat httpd-port)
 
 assert_result() {
     test_string=$1
