@@ -4,6 +4,8 @@ set -euo pipefail
 
 . $(dirname $0)/libtest.sh
 
+skip_revokefs_without_fuse
+
 echo "1..7"
 
 setup_repo
@@ -13,7 +15,7 @@ COMMIT=`${FLATPAK} ${U} info --show-commit org.test.Hello`
 
 ${FLATPAK} info -rcos  org.test.Hello > info
 
-assert_file_has_content info "^app/org.test.Hello/$(flatpak --default-arch)/master test-repo ${COMMIT}"
+assert_file_has_content info "^app/org\.test\.Hello/$(flatpak --default-arch)/master test-repo ${COMMIT}"
 
 echo "ok info -rcos"
 
@@ -25,25 +27,25 @@ echo "ok info --show-permissions"
 
 ${FLATPAK} info --show-location  org.test.Hello > info
 
-assert_file_has_content info "app/org.test.Hello/$(flatpak --default-arch)/master/${COMMIT}"
+assert_file_has_content info "app/org\.test\.Hello/$(flatpak --default-arch)/master/${COMMIT}"
 
 echo "ok info --show-location"
 
 ${FLATPAK} info --show-runtime  org.test.Hello > info
 
-assert_file_has_content info "^org.test.Platform/$(flatpak --default-arch)/master$"
+assert_file_has_content info "^org\.test\.Platform/$(flatpak --default-arch)/master$"
 
 echo "ok info --show-runtime"
 
 ${FLATPAK} info --show-sdk  org.test.Hello > info
 
-assert_file_has_content info "^org.test.Platform/$(flatpak --default-arch)/master$"
+assert_file_has_content info "^org\.test\.Platform/$(flatpak --default-arch)/master$"
 
 echo "ok info --show-sdk"
 
 ${FLATPAK} info --show-extensions org.test.Hello > info
 
-assert_file_has_content info "Extension: runtime/org.test.Hello.Locale/$(flatpak --default-arch)/master$"
+assert_file_has_content info "Extension: runtime/org\.test\.Hello\.Locale/$(flatpak --default-arch)/master$"
 
 echo "ok info --show-extensions"
 
